diff --git a/src/libknot/packet/response.c b/src/libknot/packet/response.c
index 60f6685..9a5e813 100644
--- a/src/libknot/packet/response.c
+++ b/src/libknot/packet/response.c
@@ -20,6 +20,7 @@
 
 #include "libknot/packet/response.h"
 #include "libknot/util/wire.h"
+#include "libknot/util/tolower.h"
 #include "libknot/common.h"
 #include "libknot/util/debug.h"
 #include "libknot/rrset.h"
@@ -28,6 +29,22 @@
 
 /*----------------------------------------------------------------------------*/
 
+static bool compr_label_match(const uint8_t *n, const uint8_t *p)
+{
+		if (*n != *p) {
+			return false;
+		}
+
+		uint8_t len = *n;
+		for (uint8_t i = 0; i < len; ++i) {
+			if (knot_tolower(n[1 + i]) != knot_tolower(p[1 + i])) {
+				return false;
+			}
+		}
+
+		return true;
+}
+
 /*!
  * \brief Compare suffixes and calculate score (number of matching labels).
  *
@@ -44,7 +61,7 @@ static bool knot_response_compr_score(const uint8_t *n, const uint8_t *p,
 		if (score + labels <= match->lbcount)
 			return false; /* Early cut. */
 		/* Keep track of contiguous matches. */
-		if (*n == *p && memcmp(n + 1, p + 1, *n) == 0) {
+		if (compr_label_match(n, p)) {
 			if (score == 0)
 				off = (p - wire);
 			++score;
